@@ -30,7 +30,9 @@ local function gen_exclude_flags_filter(exclude_flags)
   return function(u)
     local got_flags = u:get_flags()
     for _, flag in ipairs(exclude_flags) do
-      if got_flags[flag] then return false end
+      if got_flags[flag] then
+        return false
+      end
     end
     return true
   end
@@ -44,11 +46,11 @@ local extractors = {
         return args[1], 'string'
       end
 
-      return '','string'
+      return '', 'string'
     end,
     ['description'] = [[Return value from function's argument or an empty string,
 For example, `id('Something')` returns a string 'Something']],
-    ['args_schema'] = {ts.string:is_optional()}
+    ['args_schema'] = { ts.string:is_optional() }
   },
   -- Similar but for making lists
   ['list'] = {
@@ -57,7 +59,7 @@ For example, `id('Something')` returns a string 'Something']],
         return fun.map(tostring, args), 'string_list'
       end
 
-      return {},'string_list'
+      return {}, 'string_list'
     end,
     ['description'] = [[Return a list from function's arguments or an empty list,
 For example, `list('foo', 'bar')` returns a list {'foo', 'bar'}]],
@@ -66,7 +68,9 @@ For example, `list('foo', 'bar')` returns a list {'foo', 'bar'}]],
   ['ip'] = {
     ['get_value'] = function(task)
       local ip = task:get_ip()
-      if ip and ip:is_valid() then return ip,'userdata' end
+      if ip and ip:is_valid() then
+        return ip, 'userdata'
+      end
       return nil
     end,
     ['description'] = [[Get source IP address]],
@@ -81,7 +85,7 @@ For example, `list('foo', 'bar')` returns a list {'foo', 'bar'}]],
         from = task:get_from(0)
       end
       if ((from or E)[1] or E).addr then
-        return from[1],'table'
+        return from[1], 'table'
       end
       return nil
     end,
@@ -97,7 +101,7 @@ uses any type by default)]],
         rcpts = task:get_recipients(0)
       end
       if ((rcpts or E)[1] or E).addr then
-        return rcpts,'table_list'
+        return rcpts, 'table_list'
       end
       return nil
     end,
@@ -111,7 +115,7 @@ uses any type by default)]],
       if not country then
         return nil
       else
-        return country,'string'
+        return country, 'string'
       end
     end,
     ['description'] = [[Get country (ASN module must be executed first)]],
@@ -124,7 +128,7 @@ uses any type by default)]],
       if not asn then
         return nil
       else
-        return asn,'string'
+        return asn, 'string'
       end
     end,
     ['description'] = [[Get AS number (ASN module must be executed first)]],
@@ -136,7 +140,7 @@ uses any type by default)]],
       if not auser then
         return nil
       else
-        return auser,'string'
+        return auser, 'string'
       end
     end,
     ['description'] = 'Get authenticated user name',
@@ -144,14 +148,14 @@ uses any type by default)]],
   -- Get principal recipient
   ['to'] = {
     ['get_value'] = function(task)
-      return task:get_principal_recipient(),'string'
+      return task:get_principal_recipient(), 'string'
     end,
     ['description'] = 'Get principal recipient',
   },
   -- Get content digest
   ['digest'] = {
     ['get_value'] = function(task)
-      return task:get_digest(),'string'
+      return task:get_digest(), 'string'
     end,
     ['description'] = 'Get content digest',
   },
@@ -160,14 +164,14 @@ uses any type by default)]],
     ['get_value'] = function(task, args)
       local parts = task:get_parts() or E
       local digests = {}
-      for i,p in ipairs(parts) do
+      for i, p in ipairs(parts) do
         if p:is_attachment() then
           table.insert(digests, common.get_cached_or_raw_digest(task, i, p, args))
         end
       end
 
       if #digests > 0 then
-        return digests,'string_list'
+        return digests, 'string_list'
       end
 
       return nil
@@ -184,7 +188,7 @@ the second optional argument is optional hash type (`blake2`, `sha256`, `sha1`,
       local parts = task:get_parts() or E
       local files = {}
 
-      for _,p in ipairs(parts) do
+      for _, p in ipairs(parts) do
         local fname = p:get_filename()
         if fname then
           table.insert(files, fname)
@@ -192,7 +196,7 @@ the second optional argument is optional hash type (`blake2`, `sha256`, `sha1`,
       end
 
       if #files > 0 then
-        return files,'string_list'
+        return files, 'string_list'
       end
 
       return nil
@@ -205,7 +209,7 @@ the second optional argument is optional hash type (`blake2`, `sha256`, `sha1`,
       local text_parts = task:get_text_parts() or E
       local languages = {}
 
-      for _,p in ipairs(text_parts) do
+      for _, p in ipairs(text_parts) do
         local lang = p:get_language()
         if lang then
           table.insert(languages, lang)
@@ -213,7 +217,7 @@ the second optional argument is optional hash type (`blake2`, `sha256`, `sha1`,
       end
 
       if #languages > 0 then
-        return languages,'string_list'
+        return languages, 'string_list'
       end
 
       return nil
@@ -223,7 +227,7 @@ the second optional argument is optional hash type (`blake2`, `sha256`, `sha1`,
   -- Get helo value
   ['helo'] = {
     ['get_value'] = function(task)
-      return task:get_helo(),'string'
+      return task:get_helo(), 'string'
     end,
     ['description'] = 'Get helo value',
   },
@@ -238,20 +242,20 @@ the second optional argument is optional hash type (`blake2`, `sha256`, `sha1`,
         end
 
         if args[2]:match('full') then
-          return task:get_header_full(args[1], strong),'table_list'
+          return task:get_header_full(args[1], strong), 'table_list'
         end
 
-        return task:get_header(args[1], strong),'string'
+        return task:get_header(args[1], strong), 'string'
       else
-        return task:get_header(args[1]),'string'
+        return task:get_header(args[1]), 'string'
       end
     end,
     ['description'] = [[Get header with the name that is expected as an argument.
 The optional second argument accepts list of flags:
   - `full`: returns all headers with this name with all data (like task:get_header_full())
   - `strong`: use case sensitive match when matching header's name]],
-    ['args_schema'] = {ts.string,
-                       (ts.pattern("strong") + ts.pattern("full")):is_optional()}
+    ['args_schema'] = { ts.string,
+                        (ts.pattern("strong") + ts.pattern("full")):is_optional() }
   },
   -- Get list of received headers (returns list of tables)
   ['received'] = {
@@ -261,10 +265,12 @@ The optional second argument accepts list of flags:
         return nil
       end
       if args[1] then
-        return fun.map(function(r) return r[args[1]] end, rh), 'string_list'
+        return fun.map(function(r)
+          return r[args[1]]
+        end, rh), 'string_list'
       end
 
-      return rh,'table_list'
+      return rh, 'table_list'
     end,
     ['description'] = [[Get list of received headers.
 If no arguments specified, returns list of tables. Otherwise, selects a specific element,
@@ -278,9 +284,11 @@ e.g. `by_hostname`]],
         return nil
       end
       if args[1] then
-        return fun.map(function(r) return r[args[1]](r) end, urls), 'string_list'
+        return fun.map(function(r)
+          return r[args[1]](r)
+        end, urls), 'string_list'
       end
-      return urls,'userdata_list'
+      return urls, 'userdata_list'
     end,
     ['description'] = [[Get list of all urls.
 If no arguments specified, returns list of url objects. Otherwise, calls a specific method,
@@ -299,21 +307,21 @@ e.g. `get_tld`]],
       if not urls[1] then
         return nil
       end
-      return urls,'userdata_list'
+      return urls, 'userdata_list'
     end,
     ['description'] = [[Get most specific urls. Arguments are equal to the Lua API function]],
-    ['args_schema'] = {ts.shape{
+    ['args_schema'] = { ts.shape {
       limit = ts.number + ts.string / tonumber,
       esld_limit = (ts.number + ts.string / tonumber):is_optional(),
       exclude_flags = url_flags_ts,
       flags = url_flags_ts,
-      flags_mode = ts.one_of{'explicit'}:is_optional(),
+      flags_mode = ts.one_of { 'explicit' }:is_optional(),
       prefix = ts.string:is_optional(),
       need_content = (ts.boolean + ts.string / lua_util.toboolean):is_optional(),
       need_emails = (ts.boolean + ts.string / lua_util.toboolean):is_optional(),
       need_images = (ts.boolean + ts.string / lua_util.toboolean):is_optional(),
       ignore_redirected = (ts.boolean + ts.string / lua_util.toboolean):is_optional(),
-    }}
+    } }
   },
   ['specific_urls_filter_map'] = {
     ['get_value'] = function(task, args)
@@ -331,21 +339,23 @@ e.g. `get_tld`]],
       if not urls[1] then
         return nil
       end
-      return fun.filter(function(u) return map:get_key(tostring(u)) end, urls),'userdata_list'
+      return fun.filter(function(u)
+        return map:get_key(tostring(u))
+      end, urls), 'userdata_list'
     end,
     ['description'] = [[Get most specific urls, filtered by some map. Arguments are equal to the Lua API function]],
-    ['args_schema'] = {ts.string, ts.shape{
+    ['args_schema'] = { ts.string, ts.shape {
       limit = ts.number + ts.string / tonumber,
       esld_limit = (ts.number + ts.string / tonumber):is_optional(),
       exclude_flags = url_flags_ts,
       flags = url_flags_ts,
-      flags_mode = ts.one_of{'explicit'}:is_optional(),
+      flags_mode = ts.one_of { 'explicit' }:is_optional(),
       prefix = ts.string:is_optional(),
       need_content = (ts.boolean + ts.string / lua_util.toboolean):is_optional(),
       need_emails = (ts.boolean + ts.string / lua_util.toboolean):is_optional(),
       need_images = (ts.boolean + ts.string / lua_util.toboolean):is_optional(),
       ignore_redirected = (ts.boolean + ts.string / lua_util.toboolean):is_optional(),
-    }}
+    } }
   },
   -- URLs filtered by flags
   ['urls_filtered'] = {
@@ -354,13 +364,13 @@ e.g. `get_tld`]],
       if not urls[1] then
         return nil
       end
-      return urls,'userdata_list'
+      return urls, 'userdata_list'
     end,
     ['description'] = [[Get list of all urls filtered by flags_include/exclude
 (see rspamd_task:get_urls_filtered for description)]],
-    ['args_schema'] = {ts.array_of{
+    ['args_schema'] = { ts.array_of {
       url_flags_ts:is_optional(), url_flags_ts:is_optional()
-    }}
+    } }
   },
   -- Get all emails
   ['emails'] = {
@@ -370,9 +380,11 @@ e.g. `get_tld`]],
         return nil
       end
       if args[1] then
-        return fun.map(function(r) return r[args[1]](r) end, urls), 'string_list'
+        return fun.map(function(r)
+          return r[args[1]](r)
+        end, urls), 'string_list'
       end
-      return urls,'userdata_list'
+      return urls, 'userdata_list'
     end,
     ['description'] = [[Get list of all emails.
 If no arguments specified, returns list of url objects. Otherwise, calls a specific method,
@@ -383,11 +395,11 @@ e.g. `get_user`]],
   ['pool_var'] = {
     ['get_value'] = function(task, args)
       local type = args[2] or 'string'
-      return task:get_mempool():get_variable(args[1], type),(type)
+      return task:get_mempool():get_variable(args[1], type), (type)
     end,
     ['description'] = [[Get specific pool var. The first argument must be variable name,
 the second argument is optional and defines the type (string by default)]],
-    ['args_schema'] = {ts.string, ts.string:is_optional()}
+    ['args_schema'] = { ts.string, ts.string:is_optional() }
   },
   -- Get value of specific key from task cache
   ['task_cache'] = {
@@ -406,35 +418,35 @@ the second argument is optional and defines the type (string by default)]],
     end,
     ['description'] = [[Get value of specific key from task cache. The first argument must be
 the key name]],
-    ['args_schema'] = {ts.string}
+    ['args_schema'] = { ts.string }
   },
   -- Get specific HTTP request header. The first argument must be header name.
   ['request_header'] = {
     ['get_value'] = function(task, args)
       local hdr = task:get_request_header(args[1])
       if hdr then
-        return hdr,'string'
+        return hdr, 'string'
       end
 
       return nil
     end,
     ['description'] = [[Get specific HTTP request header.
 The first argument must be header name.]],
-    ['args_schema'] = {ts.string}
+    ['args_schema'] = { ts.string }
   },
   -- Get task date, optionally formatted
   ['time'] = {
     ['get_value'] = function(task, args)
       local what = args[1] or 'message'
-      local dt = task:get_date{format = what, gmt = true}
+      local dt = task:get_date { format = what, gmt = true }
 
       if dt then
         if args[2] then
           -- Should be in format !xxx, as dt is in GMT
-          return os.date(args[2], dt),'string'
+          return os.date(args[2], dt), 'string'
         end
 
-        return tostring(dt),'string'
+        return tostring(dt), 'string'
       end
 
       return nil
@@ -444,8 +456,8 @@ The first argument must be header name.]],
   - `message`: timestamp as defined by `Date` header
 
   The second argument is optional time format, see [os.date](http://pgl.yoyo.org/luai/i/os.date) description]],
-    ['args_schema'] = {ts.one_of{'connect', 'message'}:is_optional(),
-                       ts.string:is_optional()}
+    ['args_schema'] = { ts.one_of { 'connect', 'message' }:is_optional(),
+                        ts.string:is_optional() }
   },
   -- Get text words from a message
   ['words'] = {
@@ -473,13 +485,15 @@ The first argument must be header name.]],
   - `norm`: normalised words (lowercased)
   - `full`: list of tables
   ]],
-    ['args_schema'] = { ts.one_of { 'stem', 'raw', 'norm', 'full' }:is_optional()},
+    ['args_schema'] = { ts.one_of { 'stem', 'raw', 'norm', 'full' }:is_optional() },
   },
   -- Get queue ID
   ['queueid'] = {
     ['get_value'] = function(task)
       local queueid = task:get_queue_id()
-      if queueid then return queueid,'string' end
+      if queueid then
+        return queueid, 'string'
+      end
       return nil
     end,
     ['description'] = [[Get queue ID]],
@@ -488,7 +502,9 @@ The first argument must be header name.]],
   ['uid'] = {
     ['get_value'] = function(task)
       local uid = task:get_uid()
-      if uid then return uid,'string' end
+      if uid then
+        return uid, 'string'
+      end
       return nil
     end,
     ['description'] = [[Get ID of the task being processed]],
@@ -497,7 +513,9 @@ The first argument must be header name.]],
   ['messageid'] = {
     ['get_value'] = function(task)
       local mid = task:get_message_id()
-      if mid then return mid,'string' end
+      if mid then
+        return mid, 'string'
+      end
       return nil
     end,
     ['description'] = [[Get message ID]],
@@ -507,25 +525,25 @@ The first argument must be header name.]],
     ['get_value'] = function(task, args)
       local symbol = task:get_symbol(args[1], args[2])
       if symbol then
-        return symbol[1],'table'
+        return symbol[1], 'table'
       end
     end,
     ['description'] = 'Get specific symbol. The first argument must be the symbol name. ' ..
-      'The second argument is an optional shadow result name. ' ..
-      'Returns the symbol table. See task:get_symbol()',
-    ['args_schema'] = {ts.string, ts.string:is_optional()}
+        'The second argument is an optional shadow result name. ' ..
+        'Returns the symbol table. See task:get_symbol()',
+    ['args_schema'] = { ts.string, ts.string:is_optional() }
   },
   -- Get full scan result
   ['scan_result'] = {
     ['get_value'] = function(task, args)
       local res = task:get_metric_result(args[1])
       if res then
-        return res,'table'
+        return res, 'table'
       end
     end,
     ['description'] = 'Get full scan result (either default or shadow if shadow result name is specified)' ..
         'Returns the result table. See task:get_metric_result()',
-    ['args_schema'] = {ts.string:is_optional()}
+    ['args_schema'] = { ts.string:is_optional() }
   },
   -- Get list of metatokens as strings
   ['metatokens'] = {
